@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,34 +14,42 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
+from google.protobuf import timestamp_pb2  # type: ignore
 
 from google.cloud.websecurityscanner_v1.services.web_security_scanner import pagers
-from google.cloud.websecurityscanner_v1.types import crawled_url
-from google.cloud.websecurityscanner_v1.types import finding
-from google.cloud.websecurityscanner_v1.types import finding_addon
-from google.cloud.websecurityscanner_v1.types import finding_type_stats
-from google.cloud.websecurityscanner_v1.types import scan_config
-from google.cloud.websecurityscanner_v1.types import scan_run
-from google.cloud.websecurityscanner_v1.types import scan_run_error_trace
-from google.cloud.websecurityscanner_v1.types import scan_run_warning_trace
-from google.cloud.websecurityscanner_v1.types import web_security_scanner
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import WebSecurityScannerTransport, DEFAULT_CLIENT_INFO
+from google.cloud.websecurityscanner_v1.types import (
+    crawled_url,
+    finding,
+    finding_addon,
+    finding_type_stats,
+    scan_config,
+    scan_run,
+    scan_run_error_trace,
+    scan_run_warning_trace,
+    web_security_scanner,
+)
+
+from .transports.base import DEFAULT_CLIENT_INFO, WebSecurityScannerTransport
 from .transports.grpc import WebSecurityScannerGrpcTransport
 from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
 
@@ -61,7 +69,8 @@ class WebSecurityScannerClientMeta(type):
     _transport_registry["grpc_asyncio"] = WebSecurityScannerGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[WebSecurityScannerTransport]:
         """Returns an appropriate transport class.
 
@@ -172,7 +181,10 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def finding_path(
-        project: str, scan_config: str, scan_run: str, finding: str,
+        project: str,
+        scan_config: str,
+        scan_run: str,
+        finding: str,
     ) -> str:
         """Returns a fully-qualified finding string."""
         return "projects/{project}/scanConfigs/{scan_config}/scanRuns/{scan_run}/findings/{finding}".format(
@@ -192,7 +204,9 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -205,9 +219,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -216,9 +234,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -227,9 +249,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -238,10 +264,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -250,6 +280,73 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -300,50 +397,22 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, WebSecurityScannerTransport):
             # transport is a WebSecurityScannerTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -355,6 +424,15 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -371,12 +449,30 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.CreateScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Creates a new ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_create_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.CreateScanConfigRequest(
+                )
+
+                # Make the request
+                response = client.create_scan_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest, dict]):
                 The request object. Request for the `CreateScanConfig`
@@ -412,7 +508,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -421,13 +522,28 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.DeleteScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an existing ScanConfig and its child
         resources.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_delete_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.DeleteScanConfigRequest(
+                )
+
+                # Make the request
+                client.delete_scan_config(request=request)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest, dict]):
                 The request object. Request for the `DeleteScanConfig`
@@ -458,19 +574,40 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def get_scan_config(
         self,
         request: Union[web_security_scanner.GetScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Gets a ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_get_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.GetScanConfigRequest(
+                )
+
+                # Make the request
+                response = client.get_scan_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.GetScanConfigRequest, dict]):
                 The request object. Request for the `GetScanConfig`
@@ -506,7 +643,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -515,12 +657,31 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.ListScanConfigsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanConfigsPager:
         r"""Lists ScanConfigs under a given project.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_list_scan_configs():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListScanConfigsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_scan_configs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest, dict]):
                 The request object. Request for the `ListScanConfigs`
@@ -558,12 +719,20 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListScanConfigsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -573,13 +742,31 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.UpdateScanConfigRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_config.ScanConfig:
         r"""Updates a ScanConfig. This method support partial
         update of a ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_update_scan_config():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.UpdateScanConfigRequest(
+                )
+
+                # Make the request
+                response = client.update_scan_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest, dict]):
                 The request object. Request for the
@@ -617,7 +804,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -626,12 +818,30 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.StartScanRunRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Start a ScanRun according to the given ScanConfig.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_start_scan_run():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.StartScanRunRequest(
+                )
+
+                # Make the request
+                response = client.start_scan_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.StartScanRunRequest, dict]):
                 The request object. Request for the `StartScanRun`
@@ -668,7 +878,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -677,12 +892,30 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.GetScanRunRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Gets a ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_get_scan_run():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.GetScanRunRequest(
+                )
+
+                # Make the request
+                response = client.get_scan_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.GetScanRunRequest, dict]):
                 The request object. Request for the `GetScanRun` method.
@@ -718,7 +951,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -727,13 +965,32 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.ListScanRunsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListScanRunsPager:
         r"""Lists ScanRuns under a given ScanConfig, in
         descending order of ScanRun stop time.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_list_scan_runs():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListScanRunsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_scan_runs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.ListScanRunsRequest, dict]):
                 The request object. Request for the `ListScanRuns`
@@ -771,12 +1028,20 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListScanRunsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -786,12 +1051,30 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.StopScanRunRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> scan_run.ScanRun:
         r"""Stops a ScanRun. The stopped ScanRun is returned.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_stop_scan_run():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.StopScanRunRequest(
+                )
+
+                # Make the request
+                response = client.stop_scan_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.StopScanRunRequest, dict]):
                 The request object. Request for the `StopScanRun`
@@ -828,7 +1111,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -837,12 +1125,31 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.ListCrawledUrlsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCrawledUrlsPager:
         r"""List CrawledUrls under a given ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_list_crawled_urls():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListCrawledUrlsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_crawled_urls(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest, dict]):
                 The request object. Request for the `ListCrawledUrls`
@@ -880,12 +1187,20 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListCrawledUrlsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -895,12 +1210,30 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.GetFindingRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> finding.Finding:
         r"""Gets a Finding.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_get_finding():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.GetFindingRequest(
+                )
+
+                # Make the request
+                response = client.get_finding(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.GetFindingRequest, dict]):
                 The request object. Request for the `GetFinding` method.
@@ -936,7 +1269,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -945,12 +1283,31 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.ListFindingsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFindingsPager:
         r"""List Findings under a given ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_list_findings():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListFindingsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_findings(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.ListFindingsRequest, dict]):
                 The request object. Request for the `ListFindings`
@@ -988,12 +1345,20 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListFindingsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1003,12 +1368,30 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         self,
         request: Union[web_security_scanner.ListFindingTypeStatsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> web_security_scanner.ListFindingTypeStatsResponse:
         r"""List all FindingTypeStats under a given ScanRun.
 
+        .. code-block:: python
+
+            from google.cloud import websecurityscanner_v1
+
+            def sample_list_finding_type_stats():
+                # Create a client
+                client = websecurityscanner_v1.WebSecurityScannerClient()
+
+                # Initialize request argument(s)
+                request = websecurityscanner_v1.ListFindingTypeStatsRequest(
+                )
+
+                # Make the request
+                response = client.list_finding_type_stats(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest, dict]):
                 The request object. Request for the
@@ -1042,7 +1425,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
