@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,22 +15,23 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import packaging.version
-import pkg_resources
 
+import google.api_core
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 import google.auth  # type: ignore
-import google.api_core  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.websecurityscanner_v1.types import finding
-from google.cloud.websecurityscanner_v1.types import scan_config
-from google.cloud.websecurityscanner_v1.types import scan_run
-from google.cloud.websecurityscanner_v1.types import web_security_scanner
 from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
+
+from google.cloud.websecurityscanner_v1.types import (
+    finding,
+    scan_config,
+    scan_run,
+    web_security_scanner,
+)
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -41,15 +42,6 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
-try:
-    # google.auth.__version__ was added in 1.26.0
-    _GOOGLE_AUTH_VERSION = google.auth.__version__
-except AttributeError:
-    try:  # try pkg_resources if it is available
-        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
-    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
-        _GOOGLE_AUTH_VERSION = None
-
 
 class WebSecurityScannerTransport(abc.ABC):
     """Abstract transport class for WebSecurityScanner."""
@@ -94,12 +86,13 @@ class WebSecurityScannerTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
-        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
         # Save the scopes.
         self._scopes = scopes
@@ -115,7 +108,6 @@ class WebSecurityScannerTransport(abc.ABC):
             credentials, _ = google.auth.load_credentials_from_file(
                 credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
-
         elif credentials is None:
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
@@ -132,34 +124,13 @@ class WebSecurityScannerTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
-    # TODO(busunkim): This method is in the base transport
-    # to avoid duplicating code across the transport classes. These functions
-    # should be deleted once the minimum required versions of google-auth is increased.
-
-    # TODO: Remove this function once google-auth >= 1.25.0 is required
-    @classmethod
-    def _get_scopes_kwargs(
-        cls, host: str, scopes: Optional[Sequence[str]]
-    ) -> Dict[str, Optional[Sequence[str]]]:
-        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
-
-        scopes_kwargs = {}
-
-        if _GOOGLE_AUTH_VERSION and (
-            packaging.version.parse(_GOOGLE_AUTH_VERSION)
-            >= packaging.version.parse("1.25.0")
-        ):
-            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
-        else:
-            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
-
-        return scopes_kwargs
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.create_scan_config: gapic_v1.method.wrap_method(
-                self.create_scan_config, default_timeout=600.0, client_info=client_info,
+                self.create_scan_config,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.delete_scan_config: gapic_v1.method.wrap_method(
                 self.delete_scan_config,
@@ -207,10 +178,14 @@ class WebSecurityScannerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.update_scan_config: gapic_v1.method.wrap_method(
-                self.update_scan_config, default_timeout=600.0, client_info=client_info,
+                self.update_scan_config,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.start_scan_run: gapic_v1.method.wrap_method(
-                self.start_scan_run, default_timeout=600.0, client_info=client_info,
+                self.start_scan_run,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.get_scan_run: gapic_v1.method.wrap_method(
                 self.get_scan_run,
@@ -243,7 +218,9 @@ class WebSecurityScannerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.stop_scan_run: gapic_v1.method.wrap_method(
-                self.stop_scan_run, default_timeout=600.0, client_info=client_info,
+                self.stop_scan_run,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.list_crawled_urls: gapic_v1.method.wrap_method(
                 self.list_crawled_urls,
@@ -310,9 +287,9 @@ class WebSecurityScannerTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -448,5 +425,9 @@ class WebSecurityScannerTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("WebSecurityScannerTransport",)
