@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,11 @@
 #
 import proto  # type: ignore
 
-
 __protobuf__ = proto.module(
-    package="google.cloud.websecurityscanner.v1beta", manifest={"ScanConfigError",},
+    package="google.cloud.websecurityscanner.v1beta",
+    manifest={
+        "ScanConfigError",
+    },
 )
 
 
@@ -87,8 +89,15 @@ class ScanConfigError(proto.Message):
         UNSUPPORTED_FINDING_TYPE = 41
         UNSUPPORTED_URL_SCHEME = 42
 
-    code = proto.Field(proto.ENUM, number=1, enum=Code,)
-    field_name = proto.Field(proto.STRING, number=2,)
+    code = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Code,
+    )
+    field_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
